# Oneroster Python Client

This library facilitates easy access to the user database from Clever or Classlink.  
The connectors provide single-method calls that will return users (students, teachers or both) from the provider of your choice,
based on class, course, or school membership without the need for paging and response handling.  Additional documentation to come.


- https://developer.classlink.com/
- https://dev.clever.com/v2.1/reference
- https://www.imsglobal.org/oneroster-v11-final-specification

For details on the development of this library, visit https://github.com/vossenv/oneroster-python

Contact Danimae Vossen (vossen.dm@gmail.com) for inquiries


